[java-identity-provider] branch main updated: IDP-2253 - C14n flow that runs a deployer-defined bean

Scott Cantor cantor.2 at osu.edu
Wed Feb 26 14:32:07 UTC 2025


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch main
in repository java-identity-provider.

View the commit online:
http://git.shibboleth.net/view/?p=java-identity-provider.git;a=commit;h=38f1c142e34caacd380c2adbe4b99ebf1c36dc8a

The following commit(s) were added to refs/heads/main by this push:
     new 38f1c142e IDP-2253 - C14n flow that runs a deployer-defined bean
38f1c142e is described below

commit 38f1c142e34caacd380c2adbe4b99ebf1c36dc8a
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Wed Feb 26 09:31:59 2025 -0500

    IDP-2253 - C14n flow that runs a deployer-defined bean
    
    https://shibboleth.atlassian.net/browse/IDP-2353
    
    Revert marker subtype and treat all c14n flows uniformly again.
---
 ...LoginSubjectCanonicalizationFlowDescriptor.java | 29 ----------------------
 ...jectCanonicalizationFlowDescriptorManager.java} | 12 ++++-----
 .../shibboleth/idp/conf/subject-c14n-system.xml    |  4 +--
 3 files changed, 8 insertions(+), 37 deletions(-)

diff --git a/idp-authn-api/src/main/java/net/shibboleth/idp/authn/PostLoginSubjectCanonicalizationFlowDescriptor.java b/idp-authn-api/src/main/java/net/shibboleth/idp/authn/PostLoginSubjectCanonicalizationFlowDescriptor.java
deleted file mode 100644
index 7c3ff35d2..000000000
--- a/idp-authn-api/src/main/java/net/shibboleth/idp/authn/PostLoginSubjectCanonicalizationFlowDescriptor.java
+++ /dev/null
@@ -1,29 +0,0 @@
-/*
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *    http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package net.shibboleth.idp.authn;
-
-import javax.security.auth.Subject;
-
-/**
- * Marker subtype for a {@link SubjectCanonicalizationFlowDescriptor} that applies to the post-login
- * scenario of transforming the {@link Subject} produced for an {@link AuthenticationResult} into
- * a final name.
- * 
- * @since 5.2.0
- */
-public class PostLoginSubjectCanonicalizationFlowDescriptor extends SubjectCanonicalizationFlowDescriptor {
-
-
-}
\ No newline at end of file
diff --git a/idp-conf-impl/src/main/resources/net/shibboleth/idp/conf/subject-c14n-system.xml b/idp-conf-impl/src/main/resources/net/shibboleth/idp/conf/subject-c14n-system.xml
index 1ff5972d2..635d9eae0 100644
--- a/idp-conf-impl/src/main/resources/net/shibboleth/idp/conf/subject-c14n-system.xml
+++ b/idp-conf-impl/src/main/resources/net/shibboleth/idp/conf/subject-c14n-system.xml
@@ -15,7 +15,7 @@
     <!-- Management bean to collect and expose Post-Login Subject C14N flow descriptors. -->
     
     <bean id="shibboleth.PostLoginC14NFlowDescriptorManager"
-        class="net.shibboleth.idp.authn.impl.PostLoginSubjectCanonicalizationFlowDescriptorManager"
+        class="net.shibboleth.idp.authn.impl.SubjectCanonicalizationFlowDescriptorManager"
         p:components="#{getObject('shibboleth.PostLoginSubjectCanonicalizationFlows')}" />
 
     <!-- Dummy beans expected to be redefined by imported resource. -->
@@ -35,7 +35,7 @@
     <import resource="conditional:%{idp.home}/conf/c14n/x500-subject-c14n-config.xml" />
 
     <bean id="shibboleth.PostLoginSubjectCanonicalizationFlow" abstract="true"
-        class="net.shibboleth.idp.authn.PostLoginSubjectCanonicalizationFlowDescriptor" />
+        class="net.shibboleth.idp.authn.SubjectCanonicalizationFlowDescriptor" />
 
     <bean id="c14n/simple" parent="shibboleth.PostLoginSubjectCanonicalizationFlow">
         <property name="implementation">

diff --git a/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/PostLoginSubjectCanonicalizationFlowDescriptorManager.java b/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/SubjectCanonicalizationFlowDescriptorManager.java
similarity index 66%
rename from idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/PostLoginSubjectCanonicalizationFlowDescriptorManager.java
rename to idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/SubjectCanonicalizationFlowDescriptorManager.java
index cac472d22..caeca1f2a 100644
--- a/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/PostLoginSubjectCanonicalizationFlowDescriptorManager.java
+++ b/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/SubjectCanonicalizationFlowDescriptorManager.java
@@ -20,16 +20,16 @@ import javax.annotation.Nullable;
 
 import org.springframework.beans.factory.annotation.Autowired;
 
-import net.shibboleth.idp.authn.PostLoginSubjectCanonicalizationFlowDescriptor;
+import net.shibboleth.idp.authn.SubjectCanonicalizationFlowDescriptor;
 import net.shibboleth.shared.spring.config.IdentifiedComponentManager;
 
 /**
  * Manager of {@link PostLoginSubjectCanonicalizationFlowDescriptor} objects.
  * 
  * @since 5.2.0
  */
-public class PostLoginSubjectCanonicalizationFlowDescriptorManager
-        extends IdentifiedComponentManager<PostLoginSubjectCanonicalizationFlowDescriptor> {
+public class SubjectCanonicalizationFlowDescriptorManager
+        extends IdentifiedComponentManager<SubjectCanonicalizationFlowDescriptor> {
 
     /**
      * Constructor.
@@ -37,8 +37,8 @@ public class PostLoginSubjectCanonicalizationFlowDescriptorManager
      * @param freeObjects  free-standing objects
      */
     @Autowired
-    public PostLoginSubjectCanonicalizationFlowDescriptorManager(
-            @Nullable final List<PostLoginSubjectCanonicalizationFlowDescriptor> freeObjects) {
+    public SubjectCanonicalizationFlowDescriptorManager(
+            @Nullable final List<SubjectCanonicalizationFlowDescriptor> freeObjects) {
         super(freeObjects);
     }
 
@@ -20,16 +20,16 @@ import javax.annotation.Nullable;
 
 /**
- * Manager of {@link PostLoginSubjectCanonicalizationFlowDescriptor} objects.
+ * Manager of {@link SubjectCanonicalizationFlowDescriptor} objects.
  * 
  * @since 5.2.0
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list